@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2000-2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2000-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -809,7 +809,7 @@ sync_recipient_header (GMimeMessage *message, const char *type)
 	InternetAddressList *recipients;
 	
 	/* sync the specified recipient header */
-	recipients = g_mime_message_get_recipients (message, type);
+	recipients = (InternetAddressList *) g_mime_message_get_recipients (message, type);
 	if (recipients) {
 		char *string;
 		
