@@ -2,7 +2,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2002 Ximian, Inc. (www.ximian.com)
+ *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,6 +41,12 @@
 #define isblank(c) ((c) == ' ' || (c) == '\t')
 #endif /* HAVE_ISBLANK */
 
+#ifdef ENABLE_WARNINGS
+#define w(x) x
+#else
+#define w(x)
+#endif /* ENABLE_WARNINGS */
+
 #define d(x)
 
 static void g_mime_parser_class_init (GMimeParserClass *klass);
@@ -149,7 +155,7 @@ parser_pop_boundary (GMimeParser *parser)
 	struct _boundary_stack *s;
 	
 	if (!priv->bounds) {
-		g_warning ("boundary stack underflow");
+		w(g_warning ("boundary stack underflow"));
 		return;
 	}
 	
@@ -669,7 +675,7 @@ parser_step_from (GMimeParser *parser)
 	header->name = g_strndup (priv->headerbuf, hlen);                 \
 	g_strstrip (header->name);                                        \
 	if (*colon != ':') {                                              \
-		g_warning ("Invalid header: %s", header->name);           \
+		w(g_warning ("Invalid header: %s", header->name));        \
 		header->value = header->name;                             \
 		header->name = g_strdup ("X-Invalid-Header");             \
 	} else {                                                          \
@@ -725,7 +731,7 @@ parser_step_headers (GMimeParser *parser)
 			while (*inptr != '\n')
 				inptr++;
 			
-			if (inptr + 1 >= inend) {
+			if (inptr == inend) {
 				/* we don't have enough data to tell if we
 				   got all of the header or not... */
 				priv->inptr = start;
@@ -763,7 +769,6 @@ parser_step_headers (GMimeParser *parser)
 	inend = priv->inend;
 	
 	header_backup (priv, inptr, inend - inptr);
-	/*header_parse (priv, hend);*/
 	
  headers_end:
 	
@@ -1225,12 +1230,13 @@ parser_construct_multipart (GMimeParser *parser, GMimeContentType *content_type,
 		if (*found == FOUND_END_BOUNDARY && found_immediate_boundary (priv)) {
 			/* eat end boundary */
 			parser_skip_line (parser);
+			parser_pop_boundary (parser);
 			*found = parser_scan_multipart_postface (parser, multipart);
+		} else {
+			parser_pop_boundary (parser);
 		}
-		
-		parser_pop_boundary (parser);
 	} else {
-		g_warning ("multipart without boundary encountered");
+		w(g_warning ("multipart without boundary encountered"));
 		/* this will scan everything into the preface */
 		*found = parser_scan_multipart_preface (parser, multipart);
 	}
